@@ -68,7 +68,7 @@ void printHelp()
     cout<<"\n";
     cout<<" -O, --out-format=<format>      output file in given format\n";
     cout<<"                                  <format>=[html, xhtml, latex, tex, odt, rtf,\n";
-    cout<<"                                  ansi, xterm256, bbcode, pango, svg]\n";
+    cout<<"                                  ansi, xterm256, truecolor, bbcode, pango, svg]\n";
     cout<<" -c, --style-outfile=<file>     name of style file or print to stdout, if\n";
     cout<<"                                  'stdout' is given as file argument\n";
 
