@@ -96,11 +96,13 @@ CodeGenerator * CodeGenerator::getInstance ( OutputType type )
         generator = new ODTGenerator();
         break;
 #if !defined (QT)
-    case ANSI:
+    case ESC_ANSI:
         generator = new AnsiGenerator();
         break;
-    case XTERM256:
+    case ESC_XTERM256:
+    case ESC_TRUECOLOR:
         generator = new Xterm256Generator();
+        generator->setESCTrueColor(type==ESC_TRUECOLOR);
         break;
 #endif
     default:
@@ -1026,7 +1028,16 @@ void CodeGenerator::processRootState()
             openTag ( STANDARD );
             break;
         case _EOL:
+            
+            // XTERM256 fix (issue with less cmd)
+            if  (!firstLine || showLineNumbers) {
+                closeTag ( STANDARD ); 
+            }
             insertLineNumber ( !firstLine );
+            if (!firstLine || showLineNumbers) { 
+                flushWs();
+                openTag ( STANDARD );
+            }
             firstLine=false;
             break;
         case _EOF:
@@ -1092,7 +1103,7 @@ bool CodeGenerator::processSyntaxChangeState(State myState)
             exitState=true;
             break;
         }
-    } while ( ( !exitState ) && ( !eof ) );
+    } while (  !exitState  &&  !eof );
 
     closeTag ( KEYWORD );
     return eof;
@@ -1128,7 +1139,7 @@ bool CodeGenerator::processKeywordState ( State myState )
             exitState= ( myClassID!=currentKeywordClass ) || ( myState!=newState );
             break;
         }
-    } while ( ( !exitState ) && ( !eof ) );
+    } while ( !exitState  &&  !eof );
 
     closeKWTag ( myClassID );
 
@@ -1160,7 +1171,7 @@ bool CodeGenerator::processNumberState()
             exitState=newState!=NUMBER;
             break;
         }
-    } while ( ( !exitState ) && ( !eof ) );
+    } while ( !exitState && !eof );
 
     closeTag ( NUMBER );
     return eof;
@@ -1212,7 +1223,7 @@ bool CodeGenerator::processMultiLineCommentState()
         default:
             break;
         }
-    } while ( ( !exitState ) && ( !eof ) );
+    } while ( !exitState  &&  !eof );
 
     closeTag ( ML_COMMENT );
     return eof;
@@ -1255,7 +1266,7 @@ bool CodeGenerator::processSingleLineCommentState()
         default:
             break;
         }
-    } while ( ( !exitState ) && ( !eof ) );
+    } while ( !exitState  &&  !eof );
 
     closeTag ( SL_COMMENT );
     return eof;
@@ -1311,7 +1322,7 @@ bool CodeGenerator::processDirectiveState()
         default:
             break;
         }
-    } while ( ( !exitState ) && ( !eof ) );
+    } while ( !exitState && !eof );
 
     closeTag ( DIRECTIVE );
     return eof;
@@ -1398,7 +1409,7 @@ bool CodeGenerator::processStringState ( State oldState )
             printMaskedToken();
             break;
         }
-    } while ( ( !exitState ) && ( !eof ) );
+    } while ( !exitState && !eof );
 
     closeTag ( myState );
     return eof;
@@ -1430,7 +1441,7 @@ bool CodeGenerator::processSymbolState()
             exitState=newState!=SYMBOL;
             break;
         }
-    } while ( ( !exitState ) && ( !eof ) );
+    } while ( !exitState && !eof );
 
     closeTag ( SYMBOL );
     return eof;
@@ -1459,7 +1470,7 @@ bool CodeGenerator::processEscapeCharState()
             exitState=newState!=ESC_CHAR;
             break;
         }
-    } while ( ( !exitState ) && ( !eof ) );
+    } while ( !exitState && !eof );
 
     closeTag ( ESC_CHAR );
     return eof;
@@ -1488,7 +1499,7 @@ bool CodeGenerator::processInterpolationState()
             exitState=newState!=STRING_INTERPOLATION;
             break;
         }
-    } while ( ( !exitState ) && ( !eof ) );
+    } while ( !exitState && !eof );
 
     closeTag ( STRING_INTERPOLATION );
     return eof;
@@ -1661,6 +1672,7 @@ bool CodeGenerator::initPluginScript(const string& script)
     if (script.empty()) return true;
 
     try {
+         
         userScriptError="";
         Diluculum::LuaState ls;
         ls.doFile (script);
