@@ -80,6 +80,8 @@ SyntaxReader::~SyntaxReader()
     pluginChunks.clear();
 }
 
+//TODO add method to add format dependent variables (like CSS class name) for plug-in access
+//     needs to be called for each loaded syntax in CodeGenerator::loadLanguage
 void  SyntaxReader::initLuaState(Diluculum::LuaState& ls, const string& langDefPath, const string& pluginParameter, OutputType type )
 {
     // initialize Lua state with variables which can be used within scripts
@@ -124,8 +126,9 @@ void  SyntaxReader::initLuaState(Diluculum::LuaState& ls, const string& langDefP
     ls["HL_FORMAT_TEX"]=TEX;
     ls["HL_FORMAT_LATEX"]=LATEX;
     ls["HL_FORMAT_RTF"]=RTF;
-    ls["HL_FORMAT_ANSI"]=ANSI;
-    ls["HL_FORMAT_XTERM256"]=XTERM256;
+    ls["HL_FORMAT_ANSI"]=ESC_ANSI;
+    ls["HL_FORMAT_XTERM256"]=ESC_XTERM256;
+    ls["HL_FORMAT_TRUECOLOR"]=ESC_TRUECOLOR;
     ls["HL_FORMAT_HTML32"]=HTML32;
     ls["HL_FORMAT_SVG"]=SVG;
     ls["HL_FORMAT_BBCODE"]=BBCODE;
@@ -133,9 +136,8 @@ void  SyntaxReader::initLuaState(Diluculum::LuaState& ls, const string& langDefP
     ls["HL_FORMAT_ODT"]=ODTFLAT;
 }
 
-LoadResult SyntaxReader::load ( const string& langDefPath, const string& pluginReadFilePath, OutputType outputType, bool clear )
+LoadResult SyntaxReader::load ( const string& langDefPath, const string& pluginReadFilePath, OutputType outputType )
 {
-  
     currentPath=langDefPath;
     disableHighlighting=false;
 
@@ -155,8 +157,8 @@ LoadResult SyntaxReader::load ( const string& langDefPath, const string& pluginR
 
         SyntaxReader **s = (SyntaxReader **)lua_newuserdata(ls.getState(), sizeof(SyntaxReader *));
         *s=this;
-        lua_setglobal(ls.getState(), GLOBAL_INSTANCE_NAME);
-
+        lua_setglobal(ls.getState(), GLOBAL_SR_INSTANCE_NAME);
+    
         // ececute script and read values
         ls.doFile (langDefPath);
 
@@ -372,7 +374,7 @@ int SyntaxReader::luaAddKeyword (lua_State *L)
     if (lua_gettop(L)==2) {
         const char*keyword=lua_tostring(L, 1);
         unsigned int kwgroupID=lua_tonumber(L, 2);
-        lua_getglobal(L, GLOBAL_INSTANCE_NAME);
+        lua_getglobal(L, GLOBAL_SR_INSTANCE_NAME);
         SyntaxReader **a=reinterpret_cast<SyntaxReader **>(lua_touserdata(L, 3));
         if (*a) {
             (*a)->addKeyword(kwgroupID, keyword);
@@ -383,7 +385,6 @@ int SyntaxReader::luaAddKeyword (lua_State *L)
     return 1;
 }
 
-
 void SyntaxReader::restoreLangEndDelim(const string& langPath)
 {
     //TODO exitDelimiters be left static?
