@@ -29,7 +29,6 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #include <sstream>
 #include <iostream>
 
-
 namespace highlight
 {
 
@@ -41,7 +40,6 @@ ThemeReader::~ThemeReader()
     for (unsigned int i=0; i<pluginChunks.size(); i++) {
         delete pluginChunks[i];
     }
-
 }
 
 void ThemeReader::initStyle(ElementStyle& style, const Diluculum::LuaVariable& var)
@@ -68,60 +66,63 @@ bool ThemeReader::load ( const string &styleDefinitionPath , OutputType type)
 {
     try {
         fileOK=true;
-        Diluculum::LuaState ls;
-        ls["HL_FORMAT_HTML"]=HTML;
-        ls["HL_FORMAT_XHTML"]=XHTML;
-        ls["HL_FORMAT_TEX"]=TEX;
-        ls["HL_FORMAT_LATEX"]=LATEX;
-        ls["HL_FORMAT_RTF"]=RTF;
-        ls["HL_FORMAT_ANSI"]=ANSI;
-        ls["HL_FORMAT_XTERM256"]=XTERM256;
-        ls["HL_FORMAT_HTML32"]=HTML32;
-        ls["HL_FORMAT_SVG"]=SVG;
-        ls["HL_FORMAT_BBCODE"]=BBCODE;
-        ls["HL_FORMAT_PANGO"]=PANGO;
-        ls["HL_FORMAT_ODT"]=ODTFLAT;
-        ls["HL_OUTPUT"] = type;
-        ls.doString("Injections={}");
+        
+        Diluculum::LuaState luaState; 
+        
+        luaState["HL_FORMAT_HTML"]=HTML;
+        luaState["HL_FORMAT_XHTML"]=XHTML;
+        luaState["HL_FORMAT_TEX"]=TEX;
+        luaState["HL_FORMAT_LATEX"]=LATEX;
+        luaState["HL_FORMAT_RTF"]=RTF;
+        luaState["HL_FORMAT_ANSI"]=ESC_ANSI;
+        luaState["HL_FORMAT_XTERM256"]=ESC_XTERM256;
+        luaState["HL_FORMAT_TRUECOLOR"]=ESC_TRUECOLOR;
+        luaState["HL_FORMAT_HTML32"]=HTML32;
+        luaState["HL_FORMAT_SVG"]=SVG;
+        luaState["HL_FORMAT_BBCODE"]=BBCODE;
+        luaState["HL_FORMAT_PANGO"]=PANGO;
+        luaState["HL_FORMAT_ODT"]=ODTFLAT;
+        luaState["HL_OUTPUT"] = type;
+        luaState.doString("Injections={}");
 
-        ls.doFile (styleDefinitionPath);
+        luaState.doFile (styleDefinitionPath);
 
-        desc = ls["Description"].value().asString();
+        desc = luaState["Description"].value().asString();
 
         if (pluginChunks.size()) {
             Diluculum::LuaValueList params;
             params.push_back(desc);
             for (unsigned int i=0; i<pluginChunks.size(); i++) {
-                ls.call(*pluginChunks[i], params, "theme user function");
+                luaState.call(*pluginChunks[i], params, "theme user function");
             }
         }
 
-        initStyle(canvas, ls["Canvas"]);
-        initStyle(defaultElem, ls["Default"]);
-        initStyle(comment, ls["BlockComment"]);
-        initStyle(slcomment, ls["LineComment"]);
-        initStyle(directive, ls["PreProcessor"]);
-        initStyle(str, ls["String"]);
-        initStyle(escapeChar, ls["Escape"]);
-        initStyle(interpolation, ls["Interpolation"]);
-        initStyle(number, ls["Number"]);
-        initStyle(dstr, ls["StringPreProc"]);
-        initStyle(line, ls["LineNum"]);
-        initStyle(operators, ls["Operator"]);
+        initStyle(canvas, luaState["Canvas"]);
+        initStyle(defaultElem, luaState["Default"]);
+        initStyle(comment, luaState["BlockComment"]);
+        initStyle(slcomment, luaState["LineComment"]);
+        initStyle(directive, luaState["PreProcessor"]);
+        initStyle(str, luaState["String"]);
+        initStyle(escapeChar, luaState["Escape"]);
+        initStyle(interpolation, luaState["Interpolation"]);
+        initStyle(number, luaState["Number"]);
+        initStyle(dstr, luaState["StringPreProc"]);
+        initStyle(line, luaState["LineNum"]);
+        initStyle(operators, luaState["Operator"]);
 
         int idx=1;
         ElementStyle kwStyle;
         char kwName[5];
-        while (ls["Keywords"][idx].value() !=Diluculum::Nil) {
-            initStyle(kwStyle, ls["Keywords"][idx]);
+        while (luaState["Keywords"][idx].value() !=Diluculum::Nil) {
+            initStyle(kwStyle, luaState["Keywords"][idx]);
             snprintf(kwName, sizeof(kwName), "kw%c", ('a'+idx-1));
             keywordStyles.insert ( make_pair ( string(kwName), kwStyle ));
             idx++;
         }
 
         idx=1;
-        while (ls["Injections"][idx].value() !=Diluculum::Nil) {
-            themeInjections +=ls["Injections"][idx].value().asString();
+        while (luaState["Injections"][idx].value() !=Diluculum::Nil) {
+            themeInjections +=luaState["Injections"][idx].value().asString();
             idx++;
         }
 
