@@ -137,6 +137,16 @@ MainWindow::MainWindow(QWidget *parent)
     QObject::connect(ui->leFontSize, SIGNAL(textChanged(QString)), this, SLOT(updatePreview()));
     QObject::connect(ui->cbOmitWrappedLineNumbers, SIGNAL(clicked()), this, SLOT(updatePreview()));
 
+
+    copyShortcut = new QShortcut(QKeySequence(QKeySequence::Copy), this);
+    pasteShortcut = new QShortcut(QKeySequence(QKeySequence::Paste), this);
+
+    QObject::connect(copyShortcut, SIGNAL(activated()), ui->pbCopyToCP, SLOT(click()));
+    QObject::connect(pasteShortcut, SIGNAL(activated()), ui->pbPasteFromCB, SLOT(click()));
+
+    ui->pbCopyToCP->setText(ui->pbCopyToCP->text().arg(QKeySequence(QKeySequence::Copy).toString()));
+    ui->pbPasteFromCB->setText(ui->pbPasteFromCB->text().arg(QKeySequence(QKeySequence::Paste).toString()));
+
     setAcceptDrops(true);
 
     readSettings();
@@ -148,6 +158,8 @@ MainWindow::~MainWindow()
 {
     writeSettings();
     delete ui;
+    delete copyShortcut;
+    delete pasteShortcut;
 }
 
 void MainWindow::openFiles()
@@ -1008,15 +1020,16 @@ void MainWindow::plausibility()
 
     ui->cbPadZeroes->setEnabled(ui->cbIncLineNo->isChecked());
     ui->cbAdvWrapping->setEnabled(ui->cbWrapping->isChecked());
+    ui->sbLineLength->setEnabled(ui->cbWrapping->isChecked());
+    ui->cbOmitWrappedLineNumbers->setEnabled(ui->cbWrapping->isChecked());
     ui->comboEncoding->setEnabled(ui->cbEncoding->isChecked());
-
     ui->comboReformat->setEnabled(ui->cbReformat->isChecked());
     ui->comboKwCase->setEnabled(ui->cbKwCase->isChecked());
     ui->cbHTMLInlineCSS->setEnabled(ui->cbHTMLEmbedStyle->isChecked());
     ui->cbHTMLFileNameAnchor->setEnabled(ui->cbHTMLAnchors->isChecked());
     ui->leHTMLStyleFile->setEnabled(!ui->cbHTMLEmbedStyle->isChecked());
-    ui->leHTMLStyleIncFile->setEnabled(ui->cbHTMLEmbedStyle->isChecked() && !ui->cbHTMLInlineCSS->isChecked());
-    ui->pbHTMLChooseStyleIncFile->setEnabled(ui->cbHTMLEmbedStyle->isChecked() &&!ui->cbHTMLInlineCSS->isChecked());
+    ui->leHTMLStyleIncFile->setEnabled(!(ui->cbHTMLInlineCSS->isEnabled() && ui->cbHTMLInlineCSS->isChecked()));
+    ui->pbHTMLChooseStyleIncFile->setEnabled(!(ui->cbHTMLInlineCSS->isEnabled() && ui->cbHTMLInlineCSS->isChecked()));
     ui->leHTMLCssPrefix->setEnabled(!ui->cbHTMLInlineCSS->isChecked());
     ui->leLATEXStyleFile->setEnabled(!ui->cbLATEXEmbedStyle->isChecked());
     ui->leTEXStyleFile->setEnabled(!ui->cbTEXEmbedStyle->isChecked());
@@ -1027,13 +1040,15 @@ void MainWindow::plausibility()
     ui->sbLineNoStart->setEnabled(ui->cbIncLineNo->isChecked());
     ui->cbHTMLIndex->setEnabled(!ui->cbWrite2Src->isChecked());
     ui->cbHTMLEnclosePreTags->setEnabled(ui->cbFragment->isChecked());
-    ui->cbKeepInjections->setEnabled(ui->cbFragment->isChecked());
+    ui->cbKeepInjections->setEnabled(ui->cbFragment->isEnabled() && ui->cbFragment->isChecked());
     ui->cbHTMLAnchors->setEnabled(ui->cbIncLineNo->isChecked());
     ui->cbHTMLFileNameAnchor->setEnabled(ui->cbIncLineNo->isChecked());
     ui->cbHTMLOrderedList->setEnabled(ui->cbIncLineNo->isChecked());
-
     ui->pbCopyToCP->setEnabled(!savedClipboardContent.isEmpty());
 
+    copyShortcut->setEnabled(ui->tabIOSelection->currentWidget()==ui->tab_clipboard);
+    pasteShortcut->setEnabled(ui->tabIOSelection->currentWidget()==ui->tab_clipboard);
+
     switch (ui->comboFormat->currentIndex()) {
     case 0:
     case 1:
