@@ -209,8 +209,7 @@ public:
     */
     void setPreformatting ( WrapMode lineWrappingStyle, unsigned int lineLength,int numberSpaces );
 
-    /** \deprecated
-        \return True if document style was found */
+    /** \return True if document style was found */
     bool styleFound();
 
     /** \return True if reformatting of current input is disabled */
@@ -354,7 +353,6 @@ public:
 
     /** Load the Lua functions og the plug-in script
     	\param script path of the plug-in script
-    	\param scriptInputFile path of the optional file to be read by the plugin
     */
     bool initPluginScript(const string& script);
 
@@ -428,6 +426,10 @@ public:
     /** set SVG page size
      */
     virtual void setSVGSize ( const string&, const string& )  {};
+    
+    /** set True Color flag
+     */
+    virtual void setESCTrueColor ( bool )  {};
 
 protected:
 
@@ -578,6 +580,12 @@ protected:
         return StringTools::change_case ( encoding ) !="none";
     }
 
+    /** add Lua state variables specific to the output format */
+    /*
+    virtual void addSpecificVars()
+    {
+    };*/
+
     /** Invoke plugin decorate user function */
     Diluculum::LuaValueList callDecorateFct(const string& token);
     
@@ -608,8 +616,10 @@ private:
         return *this;
     }
 
-    /** Insert line number at the beginning of current output line */
-    virtual void insertLineNumber ( bool insertNewLine=true );
+    /** Insert line number at the beginning of current output line 
+        @param insertNewLine set true if newline should be outputted
+     */
+    virtual void insertLineNumber ( bool insertNewLine=true);
 
     /** returns output specific document footer
         @return footer */
